@@ -10,7 +10,7 @@
         int fd = cp->readFd();
 
         d_selector.addReadFd(fd);
-        d_child[fd] = cp;
+        d_child[fd].reset(cp);
 
         cerr << "Child " << d_nr << " started\n";
     }
