@@ -3,16 +3,13 @@
 //STOP
     void Monitor::stopChild(int nr, string const &)
     {
-        map<int, Child *>::iterator it =
-            find_if(d_child.begin(), d_child.end(), Find(nr));
+        auto it = find_if(d_child.begin(), d_child.end(), Find(nr));
 
         if (it == d_child.end())
-            cerr << "No child number " << nr << endl;
+            cerr << "No child number " << nr << '\n';
         else
         {
             d_selector.rmReadFd(it->second->readFd());
-
-            delete it->second;
             d_child.erase(it);
         }
     }
