@@ -9,5 +9,5 @@
         PointerUnion pu = { add };
 
         fun();
-        std::cout << pu.vp << std::endl;
+        std::cout << pu.vp << '\n';
     }
