@@ -3,12 +3,11 @@
         public:
             Binary();
             Binary(int value);
-            Binary const operator+(Binary const &rvalue);
 
             Binary &operator+=(Binary const &other);
     };
 
-    Binary const operator+(Binary const &lhs, Binary const &rhs)
+    Binary operator+(Binary const &lhs, Binary const &rhs)
     {
         Binary tmp(lhs);
         tmp += rhs;
