@@ -34,7 +34,7 @@
     {
         cout
             << "`" << Align(5, ios::left) << "hi" << "'"
-            << "`" << Align(10, ios::right) << "there" << "'" << endl;
+            << "`" << Align(10, ios::right) << "there" << "'\n";
     }
 
     /*
